@@ -1,7 +1,7 @@
 package Yars::Client;
 
 # ABSTRACT: Yet Another RESTful-Archive Service Client
-our $VERSION = '1.20'; # VERSION
+our $VERSION = '1.21'; # VERSION
 
 use strict;
 use warnings;
@@ -240,10 +240,6 @@ sub download {
                 ERROR "Yars download : $error->{code} $error->{message}";
                 last;
             }
-            if ($error->{message} =~ /connection refused/i) {
-                WARN "Yars download : $error->{message} (may retry)";
-                next;
-            }
             WARN "Error (may retry) : " . encode_json($error);
             next;
         };
@@ -558,7 +554,7 @@ Yars::Client - Yet Another RESTful-Archive Service Client
 
 =head1 VERSION
 
-version 1.20
+version 1.21
 
 =head1 SYNOPSIS
 
